@@ -25,7 +25,7 @@
  /*
   * External interface.
   */
-extern int dsn_print(ATTR_PRINT_COMMON_FN, VSTREAM *, int, void *);
+extern int dsn_print(ATTR_PRINT_COMMON_FN, VSTREAM *, int, const void *);
 
 /* LICENSE
 /* .ad
